summaryrefslogtreecommitdiff
path: root/2005/i/robert/src/ovision/see/magnifier.hh
diff options
context:
space:
mode:
authorgaillaro2005-05-06 14:43:00 +0000
committergaillaro2005-05-06 14:43:00 +0000
commit9aab8a34ad597c2b46cdde3d7cdc1e44c66c9596 (patch)
tree33dcd7b5fddb67380ad517bccfe76a9cd54b1f4a /2005/i/robert/src/ovision/see/magnifier.hh
parent1d6fa32f84b92e6dab641beb918cbb809ce1265b (diff)
modifs avant match vendredi
Diffstat (limited to '2005/i/robert/src/ovision/see/magnifier.hh')
-rw-r--r--2005/i/robert/src/ovision/see/magnifier.hh85
1 files changed, 45 insertions, 40 deletions
diff --git a/2005/i/robert/src/ovision/see/magnifier.hh b/2005/i/robert/src/ovision/see/magnifier.hh
index f569a88..0130d3b 100644
--- a/2005/i/robert/src/ovision/see/magnifier.hh
+++ b/2005/i/robert/src/ovision/see/magnifier.hh
@@ -29,52 +29,57 @@
#include "oconfig.hh"
#include "group.hh"
#include "img.hh"
+#include "eraser.hh"
/// Filtre la liste d'objets trouvées
class Magnifier
{
- /// Classe segmentation
- Segm *segm_;
- /// Classe oconfig
- OConfig *oconfig_;
- /// Classe img
- Img *img_;
- /// Liste des objects après analyse
- std::vector<Zone> *itemList_;
- /// Cible
- Group::ZoneType aim_;
+ /// Classe segmentation
+ Segm *segm_;
+ /// Classe oconfig
+ OConfig *oconfig_;
+ /// Classe img
+ Img *img_;
+ /// Classe eraser
+ Eraser *eraser_;
+ /// Liste des objects après analyse
+ std::vector<Zone> *itemList_;
+ /// Cible
+ Group::ZoneType aim_;
- public:
- /// Constructeur
- Magnifier (Img *img, Segm *segm, Group::ZoneType aim);
- /// Destructeur
- ~Magnifier (void);
- /// Analyse une liste de zones
- bool analyse (std::vector<Zone> &zoneList);
- /// Affiche les zones trouvees après analyse
- void showItems (const Group::ZoneType type) const;
- /// Renvoie une liste d'objet
- std::vector<Zone>& getItemList (Group::ZoneType type) const
- {return itemList_[type];}
- /// Affiche des infos sur une zone
- void showZone (const Zone &z) const;
+ public:
+ /// Constructeur
+ Magnifier (Img *img, Segm *segm, Eraser *eraser, Group::ZoneType aim);
+ /// Destructeur
+ ~Magnifier (void);
+ /// Analyse une liste de zones
+ bool analyse (std::vector<Zone> &zoneList);
+ /// Affiche les zones trouvees après analyse
+ void showItems (const Group::ZoneType type) const;
+ /// Renvoie une liste d'objet
+ std::vector<Zone>& getItemList (Group::ZoneType type) const
+ {return itemList_[type];}
+ /// Affiche des infos sur une zone
+ void showZone (const Zone &z) const;
- private:
- /// Ajout d'un objet
- void addItem (Zone &zone, std::vector<Zone> *list);
- void add (Zone &zone, std::vector<Zone> *list);
- /// Test si l'object s'agit d'un doublon
- bool checkIsUnique (const Zone &zone, std::vector<Zone> *list);
- bool scan ();
- /// Test si les zones sont liées
- bool areBound (const Zone &z1, const Zone &z2);
- /// Test la validité des objects
- Skittle* isSkittle (Zone &zone);
- bool isRedSkittle (const Zone &zone) const;
- bool isGreenSkittle (const Zone &zone) const;
- bool isBase (const Zone &zone) const;
- bool isBorder (const Zone &zone) const;
- bool isGap (const Zone &zone) const;
+ private:
+ /// Ajout d'un objet
+ void addItem (Zone &zone, std::vector<Zone> *list);
+ void add (Zone &zone, std::vector<Zone> *list);
+ /// Test si l'object s'agit d'un doublon
+ bool checkIsUnique (const Zone &zone, std::vector<Zone> *list);
+ bool scan ();
+ /// Test si les zones sont liées
+ bool areBound (const Zone &z1, const Zone &z2);
+ /// Test la validité des objects
+ Skittle* isSkittle (Zone &zone);
+ bool isRedSkittle (const Zone &zone) const;
+ bool isGreenSkittle (const Zone &zone) const;
+ bool isBase (const Zone &zone) const;
+ bool isBorder (const Zone &zone) const;
+ bool isGap (const Zone &zone) const;
+ /// Renvoie la position d'une quille
+ void getPosOut (Zone &zone);
};
#endif // magnifier_h